==> jc-1.4.0.tar.gz: org/dellroad/jc/vm/JarLoader.h <==
// public class org.dellroad.jc.vm.JarLoader

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f1ae443cc410a4ef org_dellroad_jc_vm_JarLoader

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_vm_JarLoader_H_
#define _JC_org_dellroad_jc_vm_JarLoader_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_vm_JarLoader$sub_refs	_jc_org_dellroad_jc_vm_JarLoader$sub_refs;
typedef struct _jc_org_dellroad_jc_vm_JarLoader$sub_nonrefs	_jc_org_dellroad_jc_vm_JarLoader$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_vm_JarLoader$refs	_jc_org_dellroad_jc_vm_JarLoader$refs;
typedef struct _jc_org_dellroad_jc_vm_JarLoader$nonrefs	_jc_org_dellroad_jc_vm_JarLoader$nonrefs;
typedef struct _jc_org_dellroad_jc_vm_JarLoader$object	_jc_org_dellroad_jc_vm_JarLoader$object;

typedef struct _jc_org_dellroad_jc_vm_JarLoader$fields_struct	_jc_org_dellroad_jc_vm_JarLoader$fields_struct;
typedef const struct _jc_org_dellroad_jc_vm_JarLoader$vmethods	_jc_org_dellroad_jc_vm_JarLoader$vmethods;
typedef const struct _jc_org_dellroad_jc_vm_JarLoader$vtable	_jc_org_dellroad_jc_vm_JarLoader$vtable;
typedef const struct _jc_org_dellroad_jc_vm_JarLoader$vtype	_jc_org_dellroad_jc_vm_JarLoader$vtype;

// Class fields structure
struct _jc_org_dellroad_jc_vm_JarLoader$fields_struct {
	struct _jc_java_lang_Class$object	*array__24Ljava__24lang__24String;
};
extern _jc_org_dellroad_jc_vm_JarLoader$fields_struct _jc_org_dellroad_jc_vm_JarLoader$class_fields;

// Constructors
extern void _jc_org_dellroad_jc_vm_JarLoader$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_dellroad_jc_vm_JarLoader$object *);

// Static methods
extern struct _jc_java_lang_Class$object *_jc_org_dellroad_jc_vm_JarLoader$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);
extern void _jc_org_dellroad_jc_vm_JarLoader$method$main$bc98a92695db8a73(_jc_env *, struct _jc_object_array *);

// Virtual methods structure
struct _jc_org_dellroad_jc_vm_JarLoader$vmethods {
};

// Vtable
struct _jc_org_dellroad_jc_vm_JarLoader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_vm_JarLoader$vmethods	org_dellroad_jc_vm_JarLoader;
};

// Vtype
struct _jc_org_dellroad_jc_vm_JarLoader$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_vm_JarLoader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_vm_JarLoader$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_vm_JarLoader$refs {
    _jc_org_dellroad_jc_vm_JarLoader$sub_refs	org_dellroad_jc_vm_JarLoader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_vm_JarLoader$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_vm_JarLoader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_vm_JarLoader$sub_nonrefs	org_dellroad_jc_vm_JarLoader;
};

// Object instance structure
struct _jc_org_dellroad_jc_vm_JarLoader$object {
	_jc_org_dellroad_jc_vm_JarLoader$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_vm_JarLoader$vtype	*vtype;
	_jc_org_dellroad_jc_vm_JarLoader$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_vm_JarLoader$vtype _jc_org_dellroad_jc_vm_JarLoader$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_vm_JarLoader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_vm_JarLoader$class_object;

#endif	/* _JC_org_dellroad_jc_vm_JarLoader_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/vm/JarLoader.h <==
// public class org.dellroad.jc.vm.JarLoader

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f1ae443cc410a4ef org_dellroad_jc_vm_JarLoader

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_vm_JarLoader_H_
#define _JC_org_dellroad_jc_vm_JarLoader_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_vm_JarLoader$sub_refs	_jc_org_dellroad_jc_vm_JarLoader$sub_refs;
typedef struct _jc_org_dellroad_jc_vm_JarLoader$sub_nonrefs	_jc_org_dellroad_jc_vm_JarLoader$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_vm_JarLoader$refs	_jc_org_dellroad_jc_vm_JarLoader$refs;
typedef struct _jc_org_dellroad_jc_vm_JarLoader$nonrefs	_jc_org_dellroad_jc_vm_JarLoader$nonrefs;
typedef struct _jc_org_dellroad_jc_vm_JarLoader$object	_jc_org_dellroad_jc_vm_JarLoader$object;

typedef struct _jc_org_dellroad_jc_vm_JarLoader$fields_struct	_jc_org_dellroad_jc_vm_JarLoader$fields_struct;
typedef const struct _jc_org_dellroad_jc_vm_JarLoader$vmethods	_jc_org_dellroad_jc_vm_JarLoader$vmethods;
typedef const struct _jc_org_dellroad_jc_vm_JarLoader$vtable	_jc_org_dellroad_jc_vm_JarLoader$vtable;
typedef const struct _jc_org_dellroad_jc_vm_JarLoader$vtype	_jc_org_dellroad_jc_vm_JarLoader$vtype;

// Class fields structure
struct _jc_org_dellroad_jc_vm_JarLoader$fields_struct {
	struct _jc_java_lang_Class$object	*array__24Ljava__24lang__24String;
};
extern _jc_org_dellroad_jc_vm_JarLoader$fields_struct _jc_org_dellroad_jc_vm_JarLoader$class_fields;

// Constructors
extern void _jc_org_dellroad_jc_vm_JarLoader$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_dellroad_jc_vm_JarLoader$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_org_dellroad_jc_vm_JarLoader$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_vm_JarLoader$method$main$bc98a92695db8a73(_jc_env *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_org_dellroad_jc_vm_JarLoader$vmethods {
};

// Vtable
struct _jc_org_dellroad_jc_vm_JarLoader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_vm_JarLoader$vmethods	org_dellroad_jc_vm_JarLoader;
};

// Vtype
struct _jc_org_dellroad_jc_vm_JarLoader$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_vm_JarLoader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_vm_JarLoader$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_vm_JarLoader$refs {
    _jc_org_dellroad_jc_vm_JarLoader$sub_refs	org_dellroad_jc_vm_JarLoader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_vm_JarLoader$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_vm_JarLoader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_vm_JarLoader$sub_nonrefs	org_dellroad_jc_vm_JarLoader;
};

// Object instance structure
struct _jc_org_dellroad_jc_vm_JarLoader$object {
	_jc_org_dellroad_jc_vm_JarLoader$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_vm_JarLoader$vtype	*vtype;
	_jc_org_dellroad_jc_vm_JarLoader$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_vm_JarLoader$vtype _jc_org_dellroad_jc_vm_JarLoader$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_vm_JarLoader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_vm_JarLoader$class_object;

#endif	/* _JC_org_dellroad_jc_vm_JarLoader_H_ */
